@@ -1,11 +1,11 @@
-from typing import List, Dict, Optional, Union
 from functools import lru_cache
+from typing import Dict, List, Optional, Union
+
 import numpy as np
 import pandas as pd
-
 from text_explainability.default import Readable
 
-from text_sensitivity.data.base import SeedMixin, CaseMixin
+from text_sensitivity.data.base import CaseMixin, SeedMixin
 
 Label = Union[str, int]
 
