@@ -45,9 +45,9 @@ def one_to_one_dictionary_mapping(instance: TextInstance,
                                   label_to: LT,
                                   tokenizer,
                                   detokenizer):
-    res = oneway_dictionary_mapping(instance, dictionary, label_from=label_from, label_to=label_to,
-                                    tokenizer=tokenizer, detokenizer=detokenizer, n=1)
-    return list(res) if res is not None else res
+    res = list(oneway_dictionary_mapping(instance, dictionary, label_from=label_from, label_to=label_to,
+                                         tokenizer=tokenizer, detokenizer=detokenizer, n=1))
+    return res[0] if res else None
 
 
 def one_to_many_dictionary_mapping(instance: TextInstance,
@@ -189,7 +189,7 @@ class OneToOnePerturbation(Perturbation):
         @text_instance
         def perturbation_function(instance: TextInstance) -> Optional[Tuple[str, LT, LT]]:
             return one_to_one_dictionary_mapping(instance,
-                                                 dictionary={k: as_list(v) for k, v in dictionary},
+                                                 dictionary={k: as_list(v) for k, v in dictionary.items()},
                                                  label_from=label_from,
                                                  label_to=label_to,
                                                  tokenizer=tokenizer,
@@ -416,9 +416,12 @@ class OneToOnePerturbation(Perturbation):
         """
         res = self.perturbation_function(instance)
 
-        if res is None or isinstance(res, list) and all(r is None for r in res):
+        if res is None or isinstance(res, list) and all(r is None for r in res) or not res:
             return
 
+        if isinstance(res, list):
+            res = res[0]
+
         perturbed, original_labels, labels = res
 
         perturbed = as_list(perturbed)
@@ -510,7 +513,7 @@ class OneToManyPerturbation(Perturbation):
         @text_instance
         def perturbation_function(instance: TextInstance) -> Optional[Tuple[str, LT, LT]]:
             return one_to_many_dictionary_mapping(instance,
-                                                  dictionary={k: as_list(v) for k, v in dictionary},
+                                                  dictionary={k: as_list(v) for k, v in dictionary.items()},
                                                   label_from=label_from,
                                                   label_to=label_to,
                                                   n=n,
